%
%  Comment Timestamps
%
%  This module provides comment timestamps. It attaches a marker of the
%  form "|T:<turn number>" to every comment you change. For example,
%  I often write to my ships what they're doing: "get fuel", "bring
%  clans". Sometimes I forget clearing the comment after performing that
%  task. This module brings a reminder -- when the comment is too old,
%  it is probably stale.
%
%  24/Mar/2002 Original version
%  07/May/2010 Fix, parameter to SetComment may not be a string
%  09/Apr/2015 PCC2 version
%

Print "[comment.q 09/Apr/2015]"

% The comment-setting command
Sub Com.SetComment (c)
  If IsEmpty(c) Then Return
  Local oldcm = RTrim(First("|T:", Comment&""))
  c := RTrim(First("|T:", c&""))
  If StrCase(c = oldcm) Then Return
  If c Then
    Comment := c & " |T:" & Turn
  Else
    Comment := Z(0)
  EndIf
EndSub

% Override the comment-setting functions.
% This is not the cleanest way because it pokes in the innards of core.q
% (which is also the reason why PCC2 comment.q differs from PCC1 comment.q).
% However, it saves quite some work redefining keys and derived commands.

% F9 on ship
Sub CC$SetShipComment
  UI.Input Translate("Enter new comment for this ship:"), Translate("Edit Comment"), 255, "gm30", RTrim(First("|T:", Comment&""))
  Com.SetComment UI.Result
EndSub

% F9 on planet
Sub CC$SetPlanetComment
  UI.Input Translate("Enter new comment for this planet:"), Translate("Edit Comment"), 255, "gm30", RTrim(First("|T:", Comment&""))
  Com.SetComment UI.Result
EndSub
